#
# spec file for package handbrake
#
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2020 B1 Systems GmbH, Vobhurg, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%ifarch x86_64
%bcond_with     qsv
%endif

Name:           handbrake
Summary:        Multithreaded Video Transcoder
Version:        1.5.1
Release:        150400.1.pm.7
Url:            http://handbrake.fr/
Source0:        https://github.com/HandBrake/HandBrake/releases/download/%{version}/HandBrake-%{version}-source.tar.bz2
Source1:        https://github.com/HandBrake/HandBrake/releases/download/%{version}/HandBrake-%{version}-source.tar.bz2.sig
Patch0:         HandBrake-no-builddate.patch
Patch1:         HandBrake-build-shared.patch
Patch2:         HandBrake-metainfo.patch
Patch3:         HandBrake-end-of-non-void-function.patch
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  meson
BuildRequires:  nasm
BuildRequires:  python > 2.7.3
BuildRequires:  subversion
BuildRequires:  update-desktop-files
BuildRequires:  wget
BuildRequires:  glibc-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(ffnvcodec)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec) >= 58
BuildRequires:  pkgconfig(libavfilter) >= 7
BuildRequires:  pkgconfig(libavformat) >= 58
BuildRequires:  pkgconfig(libavresample) >= 4
BuildRequires:  pkgconfig(libavutil) >= 56
BuildRequires:  pkgconfig(libbluray) >= 1.0.2
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libmpeg2)
BuildRequires:  pkgconfig(libswscale) >= 5
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx) >= 1.4
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(x265)
BuildRequires:  pkgconfig(zimg)
%if %{with qsv}
BuildRequires:  pkgconfig(libmfx)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(vpl)
%endif
%ifnarch %{arm}
BuildRequires:  libnuma-devel
%else
BuildRequires:  Mesa-libEGL1
BuildRequires:  Mesa-libEGL-devel
%endif

%description
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

%package cli
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description cli
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a command-line interface for Handbrake.

%package gtk
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors
Recommends:     handbrake-gtk-lang = %{version}-%{release}

%description gtk
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a GTK+ graphical user interface for Handbrake.

%lang_package -n handbrake-gtk

%prep
%setup -q -n HandBrake-%{version}
%patch0 -p0
%patch1 -p0
%if 0%{?sle_version} == 150200 && 0%{?is_opensuse}
%patch2 -p1
%endif
%patch3 -p0

%build
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-unused -I%{_includedir}/ffmpeg"
export CXXFLAGS="$CFLAGS -Wno-reorder"
export PATH="%{_builddir}/HandBrake-%{version}/build/contrib/bin:$PATH"

# try to remove build date from binaries... -- seife+obs@b1-systems.com
PKGDATE=$(date -r %{_sourcedir}/handbrake.changes +%%Y%%m%%d)
sed -i -e "s/@BUILD@/$PKGDATE/" make/configure.py

mkdir build
%configure --force \
           --build="$PWD/build" \
           --prefix=%{_prefix} \
           --strip="/bin/true" \
           --optimize=speed \
           --enable-fdk-aac \
%if %{with qsv}
           --enable-qsv \
%endif
%ifarch %{arm}
          --disable-numa \
%endif
          --enable-asm \
          --debug=max

pushd build
make libhb/handbrake/project.h
%make_build
popd

%install
%makeinstall -C build

ln -svfb ghb %{buildroot}%{_bindir}/HandBrakeGUI

%suse_update_desktop_file -r fr.handbrake.ghb AudioVideo AudioVideoEditing

# -f because it might not be there if built without gtk...
rm -vf "%{buildroot}%{_datadir}/icons"/*/*.cache

%find_lang ghb

%fdupes %{buildroot}

%files cli
%doc NEWS.markdown THANKS.markdown
%license COPYING
%{_bindir}/HandBrakeCLI

%files gtk
%doc NEWS.markdown THANKS.markdown
%license COPYING
%{_bindir}/HandBrakeGUI
%{_bindir}/ghb
%{_datadir}/applications/fr.handbrake.ghb.desktop
%{_datadir}/icons/*/*/apps/hb-icon.*
%{_datadir}/icons/hicolor/scalable/apps/fr.handbrake.ghb.svg
%if 0%{?sle_version} == 150200 && 0%{?is_opensuse}
%{_datadir}/metainfo/fr.handbrake.ghb.appdata.xml
%else
%{_datadir}/metainfo/fr.handbrake.ghb.metainfo.xml
%endif

%files -n handbrake-gtk-lang -f ghb.lang

%changelog
* Tue Jan 11 2022 enzokiel@kabelmail.de
- update to version 1.5.1
  + Build system
  - Fixed an issue with the source tarball that broke Flathub
    Builds.
  + Windows
  - The Windows UI is now .NET 6.0 only. (.NET 5.0 is no longer
    additionally required)
- version 1.5.0
  + Video
  - Fixed an issue on older Intel CPUs causing the CLI to fail to
    initialize (#3924)
  - Updated video engine to preserve chroma sample location
    information
  - Updated Intel Quick Sync to use the Intel oneAPI Video
    Processing Library (oneVPL)
  + Audio
  - Fixed MP2 audio sources not utilizing the fallback encoder
    when pass through is disabled (#3863)
  - Fixed FFmpeg AAC audio encoder quality mode scale range
    (#1295)
  + Subtitles
  - Fixed an issue with captions pass through durations (#3764)
  + Build system
  - Fixed multiple potential race conditions in Flatpak build
    process
  - Updated mac-toolchain-build script with newer tool versions
  + Third-party libraries
  - Updated libraries
    FFmpeg 4.4.1 (decoding and filters)
    FreeType 2.11.1 (subtitles)
    Fribidi 1.0.11 (subtitles)
    HarfBuzz 3.1.2 (subtitles)
    Jansson 2.14 (JSON architecture)
    libass 0.15.2 (subtitles)
    libdav1d 0.9.2 (AV1 decoding)
    libjpeg-turbo 2.1.2 (preview image compression)
    libogg 1.3.5 (Xiph codecs support)
    libvpx 1.11.0 (VP8/VP9 video encoding)
    zimg 3.0.3 (color conversion)
  + Linux
  - Fixed a filter settings issue that resulted in incorrect
    filters being added to jobs (#3910)
  - Updated Intel QSV Flatpak plugin to use Intel MediaSDK 21.3.5
  - Updated Flatpak dependencies
  - Freedesktop Platform 21.08
  - GNOME 41
  - Added Corsican (Corsu) translation
  - Updated translations
    Simplified Chinese (简体中文)
    Dutch (Nederlands)
    French (Français)
    Korean (한국어)
    Spanish (Español)
    Swedish (Svenska)
  - Miscellaneous bug fixes and improvements
  + Mac
  - Requires macOS 10.13 High Sierra or later
  - Fixed potential issues where encoding process could get stuck
    on efficiency cores in some cases
  - Fixed an issue with automatic naming not applying correctly
  - Fixed main window not being shown upon editing a job in the
    queue
  - Updated queue statistics tab to include average encoding
    speed and percent of original file size
  - Added "Move to top" and "Move to bottom" to the queue context
    menu
  - Added a stop breakpoint to the queue, set when stop after job
    is selected and may be reordered (#2572)
  - Added native support for the VideoToolbox API, enabling
    advanced features such as frame multi-pass, mastering display
    and content light metadata, and chroma location; the previous
    implementation via FFmpeg's libavcodec has been removed
  - Added Corsican (Corsu) translation
  - Updated translations
    Simplified Chinese (简体中文)
    French (Français)
    German (Deutsch)
    Italian (Italiano)
    Portuguese (Português)
  - Miscellaneous bug fixes and improvements
  + Windows
  - Requires Windows 10 or later and Microsoft .NET Desktop
    Runtime 6.0.0 or later
  - Fixed a potential crash when encoding using Intel QSV in
    2-pass mode (#4026)
  - Fixed potential issues where encoding process could get stuck
    on efficiency cores in some cases
  - Fixed an issue with static preview not updating when
    switching between automatic and custom cropping modes (#3911)
  - Updated the toolbar preset dropdown to an overlay panel that
    utilizes a tree view which saves state
  - Updated UI with various improvements to layout, typography,
    and cosmetics
  - Updated queue statistics tab to include average encoding
    speed and content information
  - Updated automatic naming file format placeholders to be live
    options
  - Updated Send File To preference to set HB_SOURCE,
    HB_DESTINATION, and HB_EXIT_CODE environment variables, which
    can be used instead of arguments
  - Added new exit_code parameter to Send File To preference
  - Added "Move to top" and "Move to bottom" to the queue context
    menu
  - Added a stop breakpoint to the queue, set when stop after job
    is selected and may be reordered (#2572)
  - Added support for Windows 10/11 notifications, enable in
    Preferences > When Done
  - Added support for Right to Left UI rendering for languages
    that require it. This can be set in preferences
  - Added Traditional Chinese (正體中文) translation
    Updated translations
    Simplified Chinese (简体中文) - includes fix for access keys
    in menus
    Corsican (Corsu)
    German (Deutsch)
    Italian (Italiano)
    Japanese (日本語)
  - Miscellaneous bug fixes and improvements
* Wed Oct  6 2021 enzokiel@kabelmail.de
- update to version 1.4.2
  + General
  - Improvements and fixes around colour bit-depth handling.
  - Fixed various issues where incorrect colour information could
    be written during muxing.
  + Hardware Encoding
  - Fixed corrupted video output when decoding HDR10 content with
    QuickSync
  + Subtitles
  - Fixed a slight subtitle colour shift issue when using libass
  + Mac
  - Fixed a build system errors that could cause failures linking
    libbluray
  - Fixed incorrect documentation URL
  - Fixed a possible crash that can occur when applying a
    malformed preset.
  + Windows
  - Added "Preset" used to the Queue summary tab.
  - Added "Save New Preset" to the preset menu, and toolbar
    preset dropdown to make it easier to find. (#3783)
  - Added category headers to the presets menu when using the
    flat display mode.
  - Changed the log filename format back to start with the
    destination filename as it did with 1.3 (#3740)
  - Changed tab selection behaviour on queue when changing jobs.
    it will no longer reset to the first tab. (#3813)
  - Fixed a minor UI juddering effect on the queue task list when
    jobs start or finish (#3813)
  - Fixed calculation errors when using padding on the dimensions
    tab (#3802)
  - Fixed an issue where static preview wasn't live-updating when
    changes occurred (#3803)
  - Fixed a crash on the Audio Defaults screen whilst trying to
    add Tracks (#3785)
  - Fixed incorrect taskbar icon state when running multiple
    encodes (#3791)
  - Fixed an issue where "None" resolution limit was not honoured
    (#3872)
  - Fixed an issue with preset export. VideoTune was not written
    correctly (#3829)
* Wed Aug 18 2021 enzokiel@kabelmail.de
- update to version 1.4.1
  + General
  - Fixed a crash when using "Align AV" on Intel based systems.
    (#3683)
  - Fixed a crash when reading certain DVD's with missing VOB
    files
  + Hardware Encoding
  - Fixed an issue with QuickSync accelerated Crop/Scale
    generating incorrect aspect ratios (#3236)
  - Fixed a crash after a subtitle scan when using the QuickSync
    encoder. (#3741)
  + Subtitles
  - Backport some libass patches which should correct some issues
    with font and font-weight selections. (#3736)
  - Fixed an issue that could prevent 3rd party software handling
    HandBrake files with dvb subtitles.
  + Command line interface
  - Fixed a regression that prevented upscaling when using -w and
  - h (#3746)
  + Linux
  - Added: flatpak permission to show bookmarks in file dialogs
    (#3748)
  + Mac
  - Fix an issue where the Quality Slider was being ignored when
    using the VideoToolbox encoder. (#3751)
  - Fixed an issue where incompatible hardware presets could be
    selected.
  + Windows
  - Windows UI builds are now available for ARM64 devices. (Named
    arm64 or aarch64 in the download section)
  - Added upgrade notices to the installer welcome page advising
    of .NET Desktop Runtime 5 requirements and to complete
    existing queue. (#3693)
  - Added support for software rendering which can be enabled to
    workaround issues with Variable Refresh Rate and 3rd party
    software causing rendering corruption (#3755)
  - Added a new preference to define how the preset toolbar
    button renders the preset list. (#3697)
  - Fixed a crash which would prevent all user settings from
    loading in some circumstances.
  - Fixed "Reset Settings" button in preferences. Certain
    settings were not reset correctly. (#3726)
  - Fixed issues with the built-in updater that may cause it to
    fail to run the installer if the app was not running as
    admin.
  - Fixed an issue that required and app restart to apply changes
    to the max simultaneous encodes setting.
  - Fixed an issue with Audio Defaults fallback encoder
    quality/bitrate/mixdown settings would not display correct
    values (#3739)
  - Fixed an with QSV multi-instance support where multiple Intel
    GPU's are used.
* Mon Jul 19 2021 enzokiel@kabelmail.de
- update to version 1.4.0
  + General
  - The HandBrake engine is now 10 and 12bit capable. Please note
    that not all filters support 10 and 12 bits. Using an 8bit
    filter will cause the pipeline to run at 8bit. Please see the
    documentation for more information.
  - HDR10 metadata will be passed through from the source file if
    present.
  - Static Previews that are generated during file scans are now
    stored in compressed jpeg format (previously stored as
    YUV420). Temporary disk space usage and disk writes are
    massively reduced. This uses libjpeg-turbo
  + Filters
  - New Filter: Chroma Smooth
  - New Filter: Colourspace Selection.
  - New Filter: Support for QuickSync hardware accelerated
    Crop/Scale when using full path.
  + Hardware Encoding
  - New Encoder: Media Foundation
    For Windows based ARM64 devices powered by Qualcomm
    Chipsets.
  - Updates to the AMD VCN encoder:
    Quality tuning for VCN's constrained vbr rate control mode.
    Results are the same or better than cqp mode, and bit rate
    is much more predictable.
    Included optimised H265 presets for 1080p and 4K content.
  - Updates to the Intel QuickSync encoder:
    Minor performance improvement by skipping VFR and
    Crop/Scale filters when they are not required.
    Overhauled memory management including improved zero-copy
    support where software filters are not used which should
    also improve performance.
  + Audio
  - MP2 Audio Passthru support.
  + Subtitles
  - New General purpose subtitle decoder
    Added support for DVB Subtitles (Passthru and Burn-In)
    Added support for EIA608 Closed Captions.
    Replaced current decoders for PGS, SRT and SSA with those
    in ffmpeg. This should correct a number of rendering issues
    on Burn-In
  - Reduced default CC burn-in font-size.
  + Third-party libraries
  - The following 3rd party libraries have changed:
    ffmpeg 4.4
    AMF 1.4.18 (AMD VCN encoding)
    nv-codec-headers 11.0.10.1 (Nvidia NVENC encoding)
    libmfx 1.34
    freetype 2.10.4
    fribidi 1.0.10
    harfbuzz 2.8.1
    jansson 2.13.1
    libass 0.15.1
    libbluray 1.3.0
    libdvdnav 6.1.1
    libdvdread 6.1.1
    dav1d 0.9.0
    libvorbis 1.3.7
    libvpx 1.10.0
    x264 161 r3043
    x265 3.5
    zimg and libjpeg-turbo are new dependencies.
  + General UI Updates (Applies to Windows, macOS and Linux)
  - The "Dimensions" tab has been redesigned.
    The Rotate and Flip filter has been moved from the filters
    tab.
    Added support for padding
    Added support to control the resolution limit.
    Added limited support for upscaling
  + Linux
  - Updated translations (levels of completeness vary)
  - Miscellaneous bug fixes and improvements
  + Mac
  - Support for Apple Silicon (macOS only)
  - Support for running multiple simultaneous jobs.
  - Support eyetv packages with .ts enclosed media file
  - Improved UI navigation
    Added two menu items to quickly switch between titles
    Improved undo/redo support
    Drag & drop import/export support in the presets popover
  - Preference Updates:
    Added a preference to control whether the current edited
    preset should be re-applied when changing title
  - Improved Security Scoped Bookmarks management
  - Minor improvements and fixes for macOS 11
  - Updated Sparkle Updater library.
  - Updated translations (levels of completeness vary)
  - Miscellaneous bug fixes and improvements
  + Windows
  - The Windows UI now requires "Microsoft .NET 5 Desktop Runtime"
    (Please note it is specifically the "Desktop Runtime!)
  - Windows 10 is now the minimum version supported. The app will
    still run on Windows 7 and 8.1 however you will receive a
    message noting that it is not supported (twice) after which
    it will continue to run. Please note some functionality may
    not work correctly on these older operating systems and no
    support will be provided.
  - Process Isolation
    When enabled, any encodes that are started are run under a
    separate "handbrake.worker.exe" process.
    This protects the main UI from any crashes that could occur
    whilst processing a file and allows the queue to continue.
    Multiple jobs can be run simultaneously to improve CPU
    utilisation on high core count systems.
  - Audio Tab
    Minor improvement to the usability of auto-passthru. To
    prevent confusion, the "auto-passhtru" audio "encoder"
    option is now only available on the defaults screen and
    not the main audio tab.
  - Queue Improvements
    Restored lost "Stop" functionality in the new queue design
    that landed in 1.3.
  - Presets
    The legacy preset side panel has been removed. The presets
    button on the toolbar will now offer a "preset manager" and
    list the available for selection.
    The inline-preset view from 1.3 is now permanent.
  - Installer Improvements
    Existing NSIS installer: Option to create a shortcut for
    "all users" as the last step.
  - Preference Updates:
    New Auto Name option: Always use the default path for each
    new source / title selected
    "Send File To" Arguments now supports "{source}" and
    "{destination}" replacement placeholders.
    Added a preference to configure the "Pause on Low Battery"
    feature.
    Check for Updates is now "opt-in" for new installs.
  - UI Performance: Optimisations to allow better performance
    when handling large sets of files (1000+)
  - Updated translations (levels of completeness vary)
  - Miscellaneous bug fixes and improvements
- Removed fix-audio-encoders-when-linking-to-FFmpeg-4.4.patch
  and HandBrake-qsv.patch, fixed upstream.
* Tue Jun 15 2021 enzokiel@kabelmail.de
- Added patch fix-audio-encoders-when-linking-to-FFmpeg-4.4.patch.
* Thu Jul 16 2020 enzokiel@kabelmail.de
- Disable mfx, handbrake crashes with message
  "Illegal Instruction (core dumped)"
* Fri Jul 10 2020 enzokiel@kabelmail.de
- Enable mfx for Leap 15.2.
* Mon Jun 15 2020 enzokiel@kabelmail.de
- update to version 1.3.3
  + General
  - Fixed ISO 639-2/B language codes not set correctly in MKV
    (affects Hebrew, Indonesian, Javanese, and Yiddish) (#2903)
  - Improved support for sources where pixel format cannot be
    quickly identified, e.g. due to delayed video track start
    (#2893)
  - Added logging to identify where hardware support is disabled
  - Miscellaneous bug fixes and improvements
  + Video
  - Improved Intel QSV memory footprint by eliminating a buffer
    pool (#2675)
  - Improved Intel QSV H.265 memory buffer size as required by
    newer Intel Media SDK (#2862)
  - Fixed and improved Intel QSV in various situations,
    especially hardware decoding (#873, #2660, #2661, #2829)
  - Fixed full range video being not being identified as limited
    range after conversion where filters are used (#2859)
  + Subtitles
  - Fixed handling of overlapping SSA import subtitles
    (791adbac)
  - Improved support for out-of-order SSA subtitles as allowed
    by specification (#2906)
  + Command line interface
  - Fixed --preset failure unless full path is specified, e.g.
  - -preset="Category Name/Preset Name" (#2838)
  + Build system
  - Improved Flatpak to better conform to freedesktop metainfo
    standards
  - Improved Intel QSV Flatpak plugin build effiency using
    cmake-ninja
  - Added a patch to fix cross compiling libdav1d using GCC 10.x
    (quality of life improvement)
    + Official HandBrake 1.3.3 Windows release is built using
    GCC 9.x and is not directly affected by this issue
  + Third-party libraries
  - Updated libraries
    + FFmpeg 4.2.3 (decoding and filters)
  + Mac
  - Fixed preview layout not displaying properly on OS X 10.11
    El Capitan
  - Fixed incorrect copyright year on About dialog (#2830)
  + Windows
  - Fixed a crash related to the dark theme (#2816)
  - Fixed a potential crash related to preview image memory
    allocation (#2871)
  - Fixed a potential crash due to certain actions causing no
    preset being selected (#2875)
  - Fixed missing E-AC-3 encoder option (#2855)
  - Fixed hardware encoder support unavailable in portable build
    (#2832)
  - Miscellaneous bug fixes and improvements
- Added HandBrake-metainfo.patch
* Mon May  4 2020 enzokiel@kabelmail.de
- update to version 1.3.2
  + General
  - Fixed point to point end detection in certain scenarios
    (#2603)
  - Improved support for H.265 video in AVI container produced by
    some security cameras (#2622)
  - Added logging to identify problematic sources where container
    and video track pixel aspect ratios differ
  - Added logging to help debug potential JSON API issues
  + Video
  - Fixed color range conversion being applied twice when scaling
    video (#2561)
  - Fixed incorrect identification of support for QSV HEVC
    encoder on older Intel hardware (#2558)
  - Added logging to identify automatic picture rotation
  - Miscellaneous bug fixes and improvements
  + Audio
  - Fixed an upstream FFmpeg issue where passing through AAC ADTS
    audio could produce invalid MKV output in rare cases
    (error instead) (#2809)
  + Filters
  - Fixed uninitialized memory in NLMeans prefilter leading to
    video corruption at bottom of picture (only affects custom
    settings) (#2576)
  - Fixed a crash in the Detelecine filter with out of bounds
    parameters (only affects custom settings) (#2560, #2804)
  + Subtitles
  - Fixed burned in subtitles position offset where cropscale
    filter is not used (#2449)
  + Command line interface
  - Fixed subtitles not being selected when specifying
  - -all-subtitles without also specifying a non-empty
  - -subtitle-lang-list
  + Build system
  - Fixed building the GTK graphical interface for use on Windows
    (link ole32)
  - Updated Flatpak manifest creation script for compatibility
    with Python 3
  - Updated Flatpak runtime and numactl library versions, QSV
    plugin
  - Improved minimum version dependencies to facilitate building
    on systems with older automake and pkg-config
  - Added a workaround for an upstream libdav1d issue affecting
    installation on FreeBSD (#2662)
  - Miscellaneous bug fixes and improvements
  + Linux
  - Fixed point to point controls not accepting fractional
    seconds
  - Fixed updating presets with identical names in different
    categories
  - Improved parity with other platforms by allowing removal of
    preset categories (automatic after last preset in category
    is removed)
  - Improved parity with other platforms by showing title and
    chapter range on the queue summary tab
  + Mac
  - Fixed selection behavior new track audio mixdown set to DPL2
    instead of stereo (#2641)
  - Fixed queued job failures related to removable drives by
    resolving security scoped resources as needed (#2566)
  + Windows
  - Fixed loading preset files with Unicode characters in path
    (#2427)
  - Fixed clear queue options to prevent them clearing active
    jobs (#2587)
  - Fixed main window status label not always reflecting the
    true count of queue jobs (#2538)
  - Fixed failure loading default settings which could cause
    various issues in the graphical interface (#2549)
  - Fixed preview images displaying incorrectly in some cases
    (anamorphic none, flip horizontal) (e9675bb, #2764)
  - Fixed various issues related to Auto Passthru, including
    fallback settings (#2619, #2627, #2611)
  - Fixed exported presets not importing correctly using the Mac
    graphical interface (#2531)
  - Fixed pause and resume not working correctly in some cases
    (#2647)
  - Fixed display of times greater than 24 hours (estimated time
    renaming, paused duration) (#2582, #2649)
  - Fixed various cosmetic issues in the graphical interface
    (#2645, #2646)
  - Improved display of long filenames in the queue (#2570)
  - Improved some UX stress cases related to the queue (#2632)
  - Improved error message when importing a preset specifying a
    nonexistent audio encoder (#2638)
  - Improved audio and subtitle languages behavior to preserve
    selected languages order where "any" is also selected (#2611)
  - Improved low disk space preferences and alerts (#2648)
  - Added a workaround for an upstream .NET issue causing
    tooltips to not render correctly in some cases (#2630)
  - Miscellaneous bug fixes and improvements
* Fri Feb 14 2020 Hillwood Yang <hillwood@opensuse.org>
- Fix a syntax mistake in spec.
* Tue Jan  7 2020 enzokiel@kabelmail.de
- update to version 1.3.1
  + General
  - Fixed potential crash when opening a DVD source
  + Video
  - Fixed rotation/flip not working properly in some cases
  - Fixed an issue with QSV failures when using --start-at
  - Updated presets using x265 to set aq-mode 1, the default
    prior to HandBrake 1.3.0
  - Improved AMD VCE rate control by always explicitly setting
    the rate control method
  - Added a workaround to fix x265 not parsing the H.265 Level
    setting where localized
  - Added an upstream patch to fix x265 limit-tu bug in loading
    co-located CU's TU depth
  - Added an upstream patch to fix x265 2-pass encoding failure
  - Added an upstream patch to fix x265 VBV macroblocking at end
    of final GOP
  + Audio
  - Fixed importing older presets where "und" was used to select
    any language track
    + Since HandBrake 1.3.0, "any" selects any language track and
    "und" selects undefined language tracks only
  - Fixed secondary audio tracks on Blu-ray sources not being
    detected in some cases
  + Subtitles
  - Fixed importing older presets where "und" was used to select
    any language track
    + Since HandBrake 1.3.0, "any" selects any language track and
    "und" selects undefined language tracks only
  + Build system
  - Fixed cpp and lib flags causing build failures on some Linux
    systems
  + Third-party libraries
  - Updated libraries
    + FFmpeg 4.2.2 (decoding and filters)
  + Linux
  - Fixed UI translations not working in some cases
  - Fixed display of chapter start times
  - Fixed small memory leak in audio list
  + Mac
  - Fixed importing external ASS/SSA subtitles
  - Fixed statistics not updating after queue completion
  - Fixed a crash that can occur when reading bluray sources.
  - Updated documentation link to the most recent documentation
    version
  + Windows
  - Fixed missing UI translations for some languages
    + Español (Spanish)
    + Français (French)
    + 한국어 (Korean)
    + русский (Russian)
    + Türkçe (Turkish)
  - Fixed official presets not updating after installing a new
    release
  - Fixed preference for automatically naming file extension
    MP4/M4V not working
  - Fixed an issue preventing the use of relative paths for
    automatic naming
  - Fixed audio and subtitles selection behavior not saving when
    set via the Save New Preset dialog
  - Fixed closed captions not being added automatically per
    selection behavior
  - Fixed iPod 5G support option displaying when an incompatible
    encoder is selected
  - Fixed queue updating slowly or not updating in some cases
  - Fixed a few UI issues and a crash with the new dark theme.
  - Fixed window not restoring properly after minimizing to
    system tray
  - Fixed frame rate mode not updating on video codec change,
    preventing QSV zero-copy mode
- Fixed HandBrake-build-shared.patch
* Wed Jan  1 2020 enzokiel@kabelmail.de
- update to version 1.3.0
  + General
  - HandBrake is now translated into many more languages
  - Redesigned queue UI
  - Removed Windows Mobile presets
    + See the [list of compatible replacements on GitHub]
    (https://github.com/HandBrake/HandBrake-docs/blob
    /03682bdd741cea425c80b06818e4bdaec75bdc5e/source/docs/en
    /latest/technical
    /official-presets.markdown#windows-mobile-presets)
  - Improved log output by silencing many lines at standard log
    level
  - Improved quality of Gmail presets slightly
  - Added Playstation 2160p60 4K Surround preset (supports PS4
    Pro)
  - Added Discord and Discord Nitro presets
  + Video
  - Updated Intel Quick Sync Video to use Direct3D 11 API
  - Updated minimum title scan duration to only apply to
    disc-based sources like Blu-ray and DVD
  - Improved detection of MPEG-1 video in program streams
  - Improved interface to FFmpeg avfilter and color handling
  - Improved Nvidia NVENC constant quality encoding slightly by
    not setting qmin and qmax
  - Replaced pp7 Deblock filter with FFmpeg Deblock filter
  - Added support for reading Ultra HD Blu-ray discs (without
    copy protection)
  - Added support for reading AV1 via libdav1d
  - Added encoding to WebM container format
  - Added Chroma Smooth filter (CLI only)
  - Added zero-copy path for Intel QSV encoding removed in a
    previous release
  - Added support for Intel QSV low power encoding (lowpower=1)
  - Added support for AMD VCE encoding on Linux via Vulkan
  - Added ability to select x265 encoder level and Fast Decode
    tune
  + Audio
  - Updated audio resampling code to use FFmpeg swresample
    instead of libsamplerate
  - Added source audio bit rate to tracks list
  - Added ability to select unknown language tracks
  - Added automatic track name pass through
  + Subtitles
  - Added ability to import external SSA/ASS subtitles
  - Added ability to select unknown language tracks
  - Added automatic track name pass through
  + Command line interface
  - Added additional unit aliases to --start-at and --stop-at,
    notably seconds and frames
  + Build system
  - HandBrake now builds with libnuma on Linux
  - Fixed Python bytestrings causing newlines to be ignored in
    build output
  - Fixed Xcode ignoring make jobs parameter and utilizing all
    CPU cores (macOS only)
  - Updated configure to enable most hardware encoders by default
    where appropriate by platform
  - Updated all scripts for compatibility with Python 3
  - Updated mac-toolchain-build script with newer tool versions
    many improvements
  - Updated mingw-w64-build script with mingw-w64 6.0.0, GCC 9.2,
    and many improvements
  - Improved compatibility with GCC 9 and recent Clang releases
  - Improved compatibility with recent Xcode releases (macOS
    only)
  - Improved host/build semantics
  - Improved namespace isolation
  - Improved handling of all options passed to configure
  - Improved configure help output
  - Improved detection of missing executable dependencies during
    configure
  - Added support for building on NetBSD
  - Added --harden configure parameter to enable buffer overflow
    protections
  - Added --sandbox configure parameter to enable sandbox build
    target on macOS
  - Added --enable-gtk4 configure parameter to build with GTK 4
    instead of GTK 3
  - Added summary of build options to configure output
  - Miscellaneous bug fixes and improvements
  + Third-party libraries
  - Removed libraries
    + libsamplerate (audio resampling)
  - Updated libraries
    + AMF 1.4.9 (AMD VCE encoding)
    + bzip2 1.0.8 (general)
    + FDK AAC 2.0.1 (AAC audio encoding, must compile from
    source)
    + FFmpeg 4.2.1 (decoding and filters)
    + FreeType 2.10.1 (subtitles)
    + Fribidi 1.0.7 (subtitles)
    + HarfBuzz 2.6.4 (subtitles)
    + Jansson 2.12 (JSON architecture)
    + libbluray 1.1.2 (Blu-ray decoding)
    + libdav1d 0.5.1 (AV1 decoding)
    + libdvdnav 6.0.1 (DVD decoding)
    + libdvdread 6.0.2 (DVD decoding)
    + libiconv 1.16 (character encoding support)
    + libmfx (Intel QSV support)
    + libogg 1.3.4 (Xiph codecs support)
    + libopus 1.3.1 (Opus audio encoding)
    + libvorbis 1.3.6 (Vorbis audio encoding)
    + libvpx 1.8.1 (VP8/VP9 video encoding)
    + libxml2 2.9.9 (general)
    + nv-codec-headers 9.0.18.1 (Nvidia NVENC encoding)
    + x265 3.2.1 (H.265/HEVC video encoding)
  + Linux
  - Fixed slider control not showing complete values
  - Updated translations (levels of completeness vary):
    + Czech
    + Chinese
    + French
    + German
    + Italian
    + Japanese
    + Korean
    + Norwegian
    + Russian
    + Spanish
    + Thai
  - Added translations (levels of completeness vary):
    + Afrikaans
    + Basque
    + Croatian
    + Dutch
    + Polish
    + Portuguese
    + Romanian
    + Slovak
    + Swedish
    + Turkish
    + Ukrainian
  - Added Intel QSV support to Flatpak (requires additional
    plugin installation)
  - Added ability to double-click to edit audio track settings
  - Added options to open encode log and log directory to actions
    menu on queue window
  - Miscellaneous bug fixes and improvements
  + Mac
  - HandBrake now requires OS X 10.11 El Capitan or later
  - HandBrake is now sandboxed and uses the macOS hardened
    runtime
  - Updated priority for low-priority threads on macOS to avoid
    potential stalls in future macOS
  - Updated translations:
    + German
  - Added translations:
    + French
    + Italian
    + Russian
  - Added preference to disable preview image on summary tab
  - Miscellaneous bug fixes and improvements
  + Windows
  - Improved browse dialog recently used to fallback to parent
    directory
  - Improved preferences layout
  - Improved auto naming collision behavior and file overwriting
  - Added preference to test selected notification sound
  - Added preference to perform when done action immmediately
    without countdown
  - Added preference to disable preview image on summary tab
  - Added hardware.enabled option to portable.ini
  - Added dark theme for Windows 10
  - Added queue import/export removed in a previous release
  - Added new low battery level and disk space safety measures
    + Encoding jobs automatically pause when battery level is
    low, system sleep is allowed, and jobs resume when power is
    restored
    + Encoding jobs automatically pause when disk space drops to
    critical levels
  - Added translations (levels of completeness vary):
    + French
    + German
    + Chinese
    + Korean
    + Russian
    + Spanish
    + Turkish
  - HandBrake now requires .NET Framework 4.7.1 or later
    (installer offers download if missing)
  - Miscellaneous bug fixes and improvements
- Removed audio_resample-issue#2126.patch, fixed upstream
- Fixed HandBrake-build-shared.patch and
  HandBrake-no-builddate.patch
- Added HandBrake-qsv.patch
* Mon Oct 14 2019 manfred.h@gmx.net
- Add patch audio_resample-issue#2126.patch to fix
  <https://github.com/HandBrake/HandBrake/issues/2124>
* Tue Feb 26 2019 enzokiel@kabelmail.de
- update to version 1.2.2
  + Mac
  - Fixed built-in application updater.
  + Windows
  - Fix crash on first launch for new installs, or older installs
    without settings.json
  - Fix an issue where the summary tab wasn't always up-to-date
* Mon Feb 18 2019 enzokiel@kabelmail.de
- update to version 1.2.1
  + General
  - Fixed potential crashes due to use of uninitialized variables
  - Improved minimum duration to only apply to DVD and BD sources
  - Miscellaneous bug fixes and improvements
  + Video
  - Fixed incorrect video rotation where rotation is explicitly
    flagged as none
  - Fixed yadif deinterlace filter not properly deinterlacing all
    frames
  - Fixed missing frame at the end of encodes from m2ts sources
  - Fixed detection of MPEG-1 video in program streams by
    improving probing of unknown streams
  - Fixed decoding of MPEG-1 video in DVD sources
  - Fixed Apple VideoToolbox encoding issues related to pyramidal
    B-frames
  - Fixed lapsharp filter corrupting frame edges
  - Improved NLMeans performance by reducing number of threads
    used with CPUs with high logical core counts
  - Improved AMD VCE encoding to enable placing key frames at
    chapter markers
  - Improved calculation of final frame duration
  - Improved support for BT.2020 color space
  + Audio
  - Fixed channel mapping for AAC 5.1 encoding (signal 5.1 Back
    instead of 5.1 Side which is less compatible)
  + Command line interface
  - Fixed selection of encoders applied to tracks selected with
    `--all-audio`
  - Fixed audio settings where more are specified than exist in
    the preset
  - Fixed overriding audio bit rate set by the preset
  + Build system
  - Fixed libvpx cross compilation with GCC 8 by disabling
    AVX-512
  - Fixed x265 cross compilation with GCC 8
  - Updated to mingw-w64-build 4.1.1 with improvements to error
    reporting and support for sha256sum on systems without shasum
  - Miscellaneous bug fixes and improvements
  + Third-party libraries
  - Updated libraries
    + libmfx (upstream API 1.27)
  + Linux
  - Fixed Flatpak icon validation by reducing resolution to pass
    new restrictions
  - Fixed Flatpak accessing gvfs mounted filesystems by adding an
    additional access permission
  - Fixed display of special characters in preset names
  - Fixed exporting presets to sanitize system reserved
    characters
  - Miscellaneous bug fixes and improvements
  + Mac
  - Fixed incorrect file extension when selecting a preset
  - Fixed potential user interface hang on macOS 10.12 Sierra
  - Fixed potential issue caused by setting work state to done
    before all threads have closed
  - Improved usability of preview controls overlay by increasing
    its size
  - Miscellaneous bug fixes and improvements
  + Windows
  - Fixed application uninstaller sometimes appearing behind the
    installer
  - Fixed potential crash when loading settings from older
    HandBrake versions
  - Fixed official presets not updating when a newer HandBrake
    version is installed
  - Fixed maximum resolution limit when selecting a preset
    (source or preset, whichever is smaller)
  - Fixed crop and anamorphic settings not being restored when
    editing a queued job
  - Fixed audio and subtitle selection behaviour where any
    language + first track are selected
  - Restored options control on the queue window previously
    removed in HandBrake 1.2.0
  - Improved user interface on displays close to the minimum
    recommended resolution
  - Improved quality of text rendering on the installer for high
    density displays
  - Improved ordering of presets and preset categories
  - Improved QSV compatibility with newer Intel drivers by
    updating libmfx
  - Improved relaunch stability by falling back to software only
    mode after hardware encoder initialization failure
  - Improved removal of small temporary files that could be left
    behind in certain cases
  - Miscellaneous bug fixes and improvements
* Sun Dec 23 2018 enzokiel@kabelmail.de
- update to version 1.2.0
  + General
  - Switched core decoding library from Libav to FFmpeg
    + Fixes numerous sources previously unreadable or otherwise
    broken
    + Facilitates a number of the improvements and features in
    this release and planned for the future
  - Removed deprecated Legacy presets
    + See the [list of compatible replacements on GitHub]
    (https://github.com/HandBrake/HandBrake-docs/blob
    /efb51cc2cd7d0c30fa5e9ee88366233ca34757a4/source
    /docs/en/latest/technical
    /official-presets.markdown#legacy-010x-presets)
  - Updated official presets to use stereo instead of DPL2 mixdown
    + Avoids potential spatial positioning issues with the current
    DPL2 algorithm and wide pans in source material
    + Limited in impact since DPL2 decoding has not been in
    widespread use for years
  - Updated official presets descriptions to revise compatibility
    and mention recently released devices
  - Updated official presets to rename Fire TV to Amazon Fire
  - Added Amazon Fire 720p30 and Chromecast 1080p60 presets
  - Added `{creation-date}` and `{creation-time}` to automatic
    file naming
  + Video
  - Fixed an issue decoding Blu-ray titles where the aspect ratio
    is unknown (assume 16:9)
  - Fixed an issue encoding video with very short frame durations
    (less than 0.00285s or greater than 350 FPS)
  - Improved extradata handling to accommodate all codecs
  - Added support for decoding TIFF/LZMA video
  + Audio
  - Fixed potential decoding issue for audio lacking an explicit
    channel layout (intelligently guess the layout)
  - Fixed a potential crash during audio probe
  - Improved resampling to allow dithering for all codecs (only
    where necessary)
  - Improved quality of the default AAC encoder on non-Mac
    platforms (FFmpeg AAC), no longer experimental
  - Improved bit rate constraints to allow Opus as low as
    6 kbit/s per channel
  - Added support for up to 7.1 channel AAC encoding (note that
    FDK AAC/HE-AAC do not support 6.1)
  - Added support for E-AC3 audio in MP4 container
  - Added Speex audio decoder
  + Subtitles
  - Fixed a potential crash where an SRT file cannot be opened
  - Added support for SRT files using periods instead of commas
    to delineate fractions
  + Command line interface
  - Fixed inability to override preset subtitles burn setting
    (`native` and `none` are now valid values for
    `--subtitle-burned`)
  + Build system
  - Fixed Linux packaging with an out-of-tree build directory
  - Fixed Windows graphical interface build script signing tool
    location
  - Removed `--enable-local-*` and associated contrib libraries;
    please see the [documentation](https://handbrake.fr/docs/)
    for dependencies help
  - Updated to mingw-w64-build 4.1.0 with gcc 7.3.0, continuous
    output (keep alive), and miscellaneous improvements
  - Improved support for building with Xcode 10
  - Improved support for building on FreeBSD 11, 12, and 13
  - Improved Flatpak packaging for Linux (numerous fixes and
    improvements, no longer experimental)
  - Improved `configure.py` to always use the Python executable
    found by `configure`
  - Added script for creating Flatpak manifests
  - Added support for selecting a compiler via the CC environment
    variable
  - Miscellaneous bug fixes and improvements
  + Third-party libraries
  - Removed libraries
    + Libav 12.3 (decoding and filters)
    + yasm 1.3.0
  - Updated libraries
    + libopus 1.3 (Opus audio encoding)
    + x264 157 r2935 (H.264/AVC video encoding)
    + x265 2.9 (H.265/HEVC video encoding)
  - New libraries
    + FFmpeg 4.1 (decoding and filters)
    + liblzma (xz) 5.2.4 (LZMA video decoding, e.g. TIFF)
    + libspeex 1.2.0 (Speex audio decoding)
  + Linux
  - Fixed Blu-ray title name being set to device name (e.g. sr0)
    when scanning raw devices
  - Fixed Blu-ray default destination file names to no longer
    include MPLS number
  - Fixed an issue with queue state not being updated properly
    on reload
  - Fixed various issues importing presets
  - Updated most translations
  - Added initial support for GTK 4
  - Added ability to customize activity window font size and
    increased default from 7 to 8
  - Added destination overwrite protection (append number to file
    name on conflict)
  - Added `{source-path}` to automatic path setting
  - Miscellaneous bug fixes and improvements
  + Mac
  - HandBrake now requires OS X 10.10 Yosemite or later
  - Removed preferences option to show the advanced tab
    (deprecated and slated for removal)
  - Fixed minor display issues on macOS 10.14 Mojave
  - Fixed queue toolbar icon not updating
  - Removed Growl in favor of native system notifications
  - Updated Sparkle automatic update library
  - Improved handling of invalid presets
  - Improved layout to better support localization
  - Improved preview border alignment on high density displays
  - Improved automatic naming to avoid updating when unrelated
    settings change
  - Improved criteria for showing destination overwrite warnings
  - Improved stop encoding confirmation dialog
  - Improved notifications to no longer play sounds when alerts
    are disabled
  - Added initial localization support and German translation
  - Added initial support for VideoToolbox hardware-accelerated
    encoding
  - Added support for Dark Mode on macOS 10.14 Mojave (new Dark
    Mode toolbar icons require building with Xcode 10 on Mojave)
  - Added Touch Bar support to various windows and dialogs
  - Added Finder progress bar to files currently encoding
  - Added Show Source in Finder to queue contextual menu (renamed
    Show in Finder to Show Destination in Finder)
  - Added validation for custom filter parameters
  - Miscellaneous bug fixes and improvements
  + Windows
  - HandBrake now requires .NET Framework 4.7.1 or later
    (installer offers download if missing)
  - Fixed mixdown selection where the specified mixdown in the
    selected preset is not available
  - Fixed audio sample rate of 48 kHz being selected where Auto
    was the specified behavior
  - Removed preferences option to show the advanced tab
    (deprecated and slated for removal)
  - Removed options menu from queue in favor of contextual menu
  - Improved layout to better support localization
  - Improved error handling when adding items to the queue
  - Improved multi-instance queue recovery to avoid loading queue
    files from the wrong instance
  - Improved filters layout and controls
  - Improved video quality slider by allowing it to grow with
    window size and setting x264/x265 granularity to 0.5
  - Improved SRT import default browse location (open source
    video location)
  - Improved keyboard shortcuts by making Ctrl-S open the
    destination save dialog (start encode is now Ctrl-E)
  - Added additional keyboard shortcuts for various actions
  - Added initial localization support and German translation
  - Added support for AMD VCE and Nvidia NVENC
    hardware-accelerated encoders
  - Added automatic queue archiving and option to select an
    archived queue for recovery (archives are removed after
    7 days)
  - Added support for recovering specific queue files on start
    using `--recover-queue-ids=<id1,id2,...>`
  - Added additional controls to passthru audio tracks to
    configure audio fallback parameters
  - Added ability to drag and drop SRT subtitles files onto the
    main window
  - Added option to disable preview image on summary tab
  - Added option to disable checking for update on start in
    portable mode
  - Added stop encoding confirmation dialog
  - Miscellaneous bug fixes and improvements
* Fri Sep  7 2018 enzokiel@kabelmail.de
- update to version 1.1.2
  + General
  - Fixed Blu-ray title name where reading from raw device
  - Improved handling of broken units in Blu-ray source (skip and
    continue reading)
  + Video
  - Fixed rare crash related to preview images, anamorphic, and
    default preset values
  - Fixed jitter produced by 59.94 fps to 29.97 fps frame rate
    conversion
  + Audio
  - Fixed duration of silence buffers (may improve audio/video
    sync for some sources)
  + Build system
  - Fixed linker warning by setting libvpx target to minimum
    supported macOS version
  - Fixed build failure with old GTK versions
  - Miscellaneous Flatpak-related fixes and improvements
  + Third-party libraries
  - Updated libraries (necessary to pull in needed bug fixes)
  - libdvdread 6.0.0 (DVD decoding)
  - libdvdnav 6.0.0 (DVD decoding)
  + Linux
  - Fixed potential crash where $HOME directory is missing
  - Fixed legacy preferences causing preset window being shown at
    every launch
  - Fixed preset name and menu display on Ubuntu 14.04 Trusty
    Tahr
  - Fixed default destination file name for Blu-ray source to not
    include MPLS number
  - Fixed queue reloading in Flatpak sandbox
  - Fixed toolbar icons alignment and use correct art for lower
    pixel density
  - Updated most translations
  + Mac
  - Fixed menu item and tooltip strings related to selection
    behavior
  - Fixed crash where presets file contains invalid UTF-8
  + Windows
  - Fixed incorrect track selection behaviours on audio and
    subtitle tabs
  - Fixed creating an unneeded HandBrake Team directory in the
    user's Roaming directory
  - Improved path handling when opening a source directory from
    the queue
  - Miscellaneous bug fixes and improvements
* Mon Jun 18 2018 enzokiel@kabelmail.de
- update to version 1.1.1
  + General
  - Fixed a potential crash in the comb detection filter
  - Fixed a potential crash in the padding filter
  + Video
  - Fixed decoding certain very high bit rate ultra-high
    definition sources with extra large packets
  - Fixed last frame in source video missing in output
  + Audio
  - Fixed crash when decoding an empty audio track
  + Build system
  - Updated mac-toolchain-build script Nasm url and improved curl
    parameters for robustness
  + Third-party libraries
  - Updated libraries (necessary to pull in needed bug fixes)
    libvpx 1.7.0 (VP8/VP9 video encoding)
    x264 155 r2901 (H.264/AVC video encoding)
  + Linux
  - Fixed Ubuntu PPA build date
  - Fixed a display issue with the quality slider control
  - Fixed issues occurring when running multiple HandBrake
    instances simultaneously
  - Updated Russian translation
  - Updated support for creating Flatpak bundles (experimental)
  - Miscellaneous bug fixes and improvements
  + Mac
  - Fixed corrupted output with VP8 and VP9 encoders
  - Fixed building x264 using Clang and -march=native/-mavx
    (thanks H. Gramner for the upstream patch)
  + Windows
  - Fixed issues with queue recovery when running multiple
    HandBrake instances simultaneously
  - Fixed an issue with a When Done action potentially causing
    the last queue item to be marked as a warning instead of
    success
  - Fixed burn-in behavior with MP4 files; after the first
    burn-in track, no additional tracks that require burn-in will
    be added
  - Improved window resize behavior for Add Selection to Queue
    dialog and allowed space bar to toggle checkbox for selected
    row
  - Improved tabbing behavior in various circumstances
  - Improved adding a new preset with the same name as an
    existing user preset; the existing preset will now be updated
    properly
  - Improved privacy by adding an option to disable the Summary
    tab preview image
  - Updated installer to block installation on 32-bit systems to
    avoid confusion (unsupported since 1.1.0)
  - Miscellaneous bug fixes and improvements
* Mon Apr  9 2018 enzokiel@kabelmail.de
- update to version 1.1.0
  + General
  - Improved user interface
  - Redesigned main window for consistency and usability;
    overall flow is top to bottom, left to right
  - Added new preset controls directly in main workflow
  - Added new summary tab for overview of settings at a glance
  - Updated interface icons to support high resolution displays
  - New and improved official presets
  - Added new presets for Vimeo and YouTube
  - Added new 2160p/4K device presets for Apple TV,
    Chromecast, Fire TV, and Roku
  - Added new Production presets for post-production video
    editing workflows
  - Added additional 2160p/4K Matroska presets
  - Improved AppleTV 4K support
  - Improved Intel QuickSync Video support
  - Added Linux support (experimental)
  - Added 10-bit H.265/HEVC encoding support for Kaby Lake and
    newer CPUs
  - Added support for multiple GPUs via D3D11 encode path
  - Many bug fixes and improvements
  + Video
  - Added new Unsharp and kernel-based Laplacian LapSharp
    sharpening filters
  - Added CSM prefilter option to NLMeans filter
  - Added support for mobile device orientation via auto-rotation
    container flag
  - x265 10- and 12-bit encoders are now included by default;
    additional dll files are no longer required
  + Command line interface
  - Added support for adaptive streaming (SPS and PPS before IDR
    frames) via the --inline-parameter-sets parameter
  - Added --json parameter to output scan/status information in
    JSON format, useful for scripting
  - Audio sample rate parameter --arate now accepts "auto" as a
    valid value
  + Build system
  - Added support for FreeBSD 11.1 (must compile from source)
  - Added support for compiling on Windows under MSYS
    (experimental, slow)
  - Updated to mingw-w64-build 3.1.1 with support for mingw-w64
    5.0.3 and gcc 7.2.0
  - Update mac-toolchain-build to add NASM 2.13.2 (now required
    for x264)
  - Miscellaneous bug fixes and improvements
  + Third-party libraries
  - Updated libraries
  - FDK AAC 0.1.5 (AAC audio encoding, must compile from source)
  - FreeType 2.8.1 (subtitles)
  - HarfBuzz 1.7.2 (subtitles)
  - Jansson 2.10 (JSON architecture)
  - LAME 3.100 (MP3 audio encoding)
  - Libav 12.3 (decoding and filters)
  - libass 0.14.0 (subtitles)
  - libbluray 1.0.2 (Blu-ray decoding)
  - libdvdnav 5.0.3 (DVD decoding)
  - libdvdread 5.0.3 (DVD decoding)
  - libiconv 1.15 (character encoding support)
  - libmfx (upstream API 1.23)
  - libogg 1.3.2 (Xiph codecs support)
  - libopus 1.2.1 (Opus audio encoding)
  - libsamplerate 0.1.9-35-g02ebb9f (audio resampling)
  - libtheora 1.1.1 (Theora video encoding)
  - libvorbis 1.3.5 (Vorbis audio encoding)
  - libvpx 1.6.1 (VP8/VP9 video encoding)
  - libxml2 2.9.4 (general)
  - x264 155 r2893 (H.264/AVC video encoding)
  - x265 2.6 (H.265/HEVC video encoding)
  - zlib 1.2.11 (general)
  + Linux
  - Added option to configure low disk space warning level
  - Added Intel QuickSync Video encoder (experimental, requires
    specific Intel driver)
  - Added support for Ubuntu 18.04 and 17.10; Ubuntu 15.04
    support is removed
  - Many other bug fixes and improvements
  + Mac
  - Added option to configure low disk space warning level
  - Improved support for VoiceOver navigation
  - Many other bug fixes and improvements
  +Windows
  - Added option to configure low disk space warning level
  - Added option to play a sound (MP3/WAV) when encode or queue
    is finished
  - Added option to show progress, pass, passcount in the
    application title or task tray icon tooltip
  - Added more granular progress reporting during search for
    start of file and muxing
  - Added support for per-display resolution awareness
  - Added support for running HandBrake in a portable mode (see
    included portable.ini.template)
  - Added custom anamorphic to dimensions tab, it's back!
  - Improved static preview window still previews rendering
  - Improved audio selection behavior controls; dropdowns are now
    context aware and range limited with better defaults
  - Improved UI constency throughout
  - Many other bug fixes and improvements
- Removed HandBrake-ffmpeg3.patch, it's no longer required.
* Fri Mar 23 2018 enzokiel@kabelmail.de
- Fixed build for SLE-12.
* Sun Dec 10 2017 antoine.belvire@opensuse.org
- Update desktop database upon handbrake-gtk installation/removal.
* Mon Oct  9 2017 seife+obs@b1-systems.com
- remove buildrequires on webkitgtk-3.0, is only needed for update
  check which is not too useful on a packaged application anyway
  and not available on Tumbleweed anymore
- add libxml2-devel buildrequires, was pulled in by webkitgtk-3.0
* Mon Apr 10 2017 joerg.lorenzen@ki.tng.de
- update to version 1.0.7
  + Video
  - Fixed decoding of raw video in Matroska/MKV.
  - Fixed time stamp handling for containerless raw video.
  - Fixed memory leaks in OpenCL.
  - Fixed x265 2-pass encoding where video frame rate is altered
    by filters.
  - Improved handling of very small amounts of sync jitter
    (~1 tick).
  - Improved handling of AVI files with broken indices.
  + Audio
  - Further refined fix for Libav crash encoding AAC at very high
    bitrates.
  + Subtitles
  - Removed fontconfig dependency on Mac and Windows; libass now
    uses CoreText/DirectWrite.
  - Improved subtitle font selection when burning in SRT/SSA
    subtitles.
  + Command line interface
  - Fixed preset subtitle burn defaults override.
  + Build system
  - Updated MinGW-w64 build script for improved compatibility
    with hardened GCC.
  + Linux
  - Fixed video preset control not updating.
  - Fixed audio passthru masks not updating until preset save.
  - Fixed application of SRT subtitles offset.
  - Updated translations: af, cs, ja_JP, ru, sk, sv.
  + Windows
  - Fixed When Done option not updating/resetting correctly.
* Sun Mar 19 2017 joerg.lorenzen@ki.tng.de
- Only build static libbluray for SLE version <= 120200.
* Mon Feb 27 2017 joerg.lorenzen@ki.tng.de
- update to version 1.0.3
  + Video
  - Fixed H.264 decoding using Libav where the initial GOP was
    dropped.
  - Fixed 2-pass x265 encoding where the source header
    incorrectly specifies frame rate.
  - Fixed 2-pass encoding with bob deinterlace and constant frame
    rate.
  - Fixed a seek issue in Libav while reading MKV sources with
    embedded subtitles.
  - Fixed multiple issues preventing Libav from opening WMV
    sources properly.
  - Fixed miscellaneous issues in Libav.
  - Fixed memory leaks in OpenCL.
  - Improved sync for streams delayed by a large amount.
  + Audio
  - Fixed a Libav crash encoding AAC at very high bitrates.
  - Fixed a potential hang in Libav while decoding AAC.
  - Improved Libav audio sync with MP4 sources containing edit
    lists.
  - Improved mapping of single channel layouts to single channel
    layouts.
  + Linux
  - Fixed a potential crash when selecting video encoders.
  - Fixed various controls not applying values properly.
  + Mac
  - Fixed a crash when attempting to edit a queued job.
  - Improved audio start point to use edit lists when encoding
    using CoreAudio AAC.
  + Windows
  - Fixed Title Specific Scan for DVD/Blu-ray.
  - Fixed broken/missing NLMeans denoise tunes.
  - Fixed an issue that could cause error -17 when encoding using
    Intel QuickSync Video.
  - Fixed an issue where the SRT language code was not being set
    correctly.
* Sun Feb 12 2017 pascal.bleser@opensuse.org
- use its own static build of libbluray as it requires a patch
* Sat Feb  4 2017 pascal.bleser@opensuse.org
- update to 1.0.2
* Mon Aug 15 2016 olaf@aepfle.de
- Accept any ffmpeg version to fix build in TW and 42.2
* Sat Feb 20 2016 joerg.lorenzen@ki.tng.de
- update to version 0.10.5
  + Removal of FDK AAC from our binary releases, --enable-fdk is
    required for "non-free" builds if compiling from source.
  - Please see out AAC Encoder Change Announcement to understand
    what this means.
  + Updated x265 to 1.9 which brings bug fixes and performance
    improvements.
  + Few minor bug fixes since the 0.10.3 release. This includes
    improvements in large AVI file handling.
- Build against ffmpeg-3.0
- version 0.10.3
  + Various bug fixes for all platforms and the core engine.
  + Updated x265 to 1.8 which brings numerous bug fixes and some
    performance improvements.
* Sat Jan  9 2016 joerg.lorenzen@ki.tng.de
- Removed all 3rd party tarballs and addded HandBrake-build-shared.patch
  to build against shared libraries.
- Disabled fdk-aac because ist's only needed for static build of
  libav/ffmpeg.
- Changed BuildRequires to pkgconfig() where possible and removed
  some unneeded dependencies.
- Enabled build for armv6l.
* Sun Jun 28 2015 seife+obs@b1-systems.com
- update to 0.10.2
  * Assorted bug fixes and performance improvements
* Tue Apr 21 2015 seife+obs@b1-systems.com
- switch to gstreamer-1.0 instead of old gstreamer-0.10 for
  distributions newer than openSUSE 11.4
* Sun Apr 19 2015 seife+obs@b1-systems.com
- update to 0.10.1:
  - various bug fixes for all platforms and the core engine
  - updated x265 to 1.5 which brings numerous bug fixes and some
  performance improvements
- do not buildrequire wget, curl, subversion -- it's not needed
- fix --prefix and DESTDIR usage to avoid build paths in binaries
  and thus unnecessary republishing
* Tue Dec  2 2014 seife+obs@b1-systems.com
- fix "no return in nonvoid function" compiler error from embedded
  libdvdnav libdvdnav-5.0.1-noreturninnonvoidfunction.patch
* Tue Dec  2 2014 seife+obs@b1-systems.com
- adjust debug config from max to std to avoid ffmpeg assert aborts
* Tue Nov 25 2014 seife+obs@b1-systems.com
- update to 0.10.0:
- remove obsolete patches, update support tarballs, only add
  the really needed stuff
- more build date removal
- important change: due to GTK3 version dependencies, the GUI
  is only built for distributions newer than openSUSE 12.3
* Fri Apr 18 2014 seife+obs@b1-systems.com
- remove build date from binaries to avoid republishing
* Sun Dec  1 2013 obs@botter.cc
- add patch to fix compiling libx264: HandBrake-0.9.9_libx264-gcc-488-fix.patch
  add -fno-aggressive-loop-optimizations to extra-cflags in
  configure for >= 13.1, see also
  https://bugs.launchpad.net/ubuntu/+source/x264/+bug/1241772
  MAY BE REMOVED on upstream fix
* Thu Jun 13 2013 dnh@opensuse.org
- update to 0.9.9
  * replace harfbuzz patch by script fragement in spec
  * update yasm, libbluray, x264, replace ffmpeg by libav
  * remove tarballs that can be system-libs
* Sat Apr  6 2013 dnh@opensuse.org
- fix conflicts with harfbuzz headers for oS >= 12.3
  see https://pmbs.links2linux.org/request/show/425
* Sun Oct  7 2012 i@marguerite.su
- update to 0.9.8
  * Corrects a few crash bugs that showed up in 0.9.7
  * Includes an AppleTV3 Preset and updated iPad Preset (0.9.7)
* Thu Mar  1 2012 pascal.bleser@opensuse.org
- update to 0.9.6
* Thu Jul  7 2011 malcolmlewis@opensuse.org
- Add BuildRequires libgudev-1_0-devel as build failing with
  'No package 'gudev-1.0' found' error.
* Tue Jan  4 2011 pascal.bleser@opensuse.org
- update to 0.9.5
* Tue Sep 21 2010 pascal.bleser@opensuse.org
- update to trunk revision 3549:
  * try other gstreamer sink interfaces if gconfvideosink fails; it appears that gconfvideosink may not work on kde systems
  * remove the 8 audio limit
  * fix cli issue with batch scan and encode
  * fix a crash when a TS has no aspect ratio set in the video stream
  * bump ffmpeg from 22950 to 25082
  * fix a rare hang in the muxer
  * GUI: fix UI problem with trellis cavlc
  * add Bluray support:
    + unencrypted BD directory trees only
    + doesn't support iso images
    + also, no PGS subtitle support yet
  * chapters and angles are supported
  * fixes memory leak during scan
  * x264 bump from r1698 to r1713:
    + introduces trellis and psy-trellis for cavlc
  * GUI: simplify source selection dialog
  * fix muxing problem with certain sources/settings
* Thu Aug 19 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3482:
  * x264 bump from r1681 to r1698: various bugfixes and improvements
* Sat Aug  7 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3473, as requested by upstream
* Fri Nov 27 2009 pascal.bleser@opensuse.org
- update to 0.9.4
* Sun Nov  1 2009 pascal.bleser@opensuse.org
- update to snapshot 2907
* Thu Oct  1 2009 pascal.bleser@opensuse.org
- downgrade to snapshot rev 2845 as per upstream request
- fix version display
- use upstream compiler flags as per upstream request
* Fri Sep 25 2009 pascal.bleser@opensuse.org
- update to rev 2844:
  * [2844] bump libtheora to official 1.1 release
  * [2843] fix srt track stop time; srt stop time was being set to the end of the start chapter instead of the end of the stop chapter
  * [2842] theora: improvements to our theora implementation:
    + support 2-pass mode which is new to theora 1.1
    + set soft target rate control so that single pass abr behaves more like theora 1.0 and doesn't look quite so awful
  * [2841] don't remove srt subs when changing from mkv to mp4
  * [2836] bump x264 to r1271 make changes required by the x264 api change fix some build issues that the x264 bump exposed
  * [2831] fix bug that was causing one sec. of audio to be dropped on many ffmpeg files
* Mon Sep 14 2009 pascal.bleser@opensuse.org
- update to rev 2822:
  * [2821] dvdnav: improved patch that guarantees forward seek moves position forward; the previous patch worked only for SEEK_CUR
  * [2822] allow dvd sources that have no audio
* Sun Sep 13 2009 pascal.bleser@opensuse.org
- update to rev 2815:
  * [2796] set use m4v preference enabled by default
  * [2797] fix PAR issue with DV For some (maybe all) DV, ffmpeg doesn't give us the sample_aspect_ratio in the context; so when it's missing, try looking it up in the AVStream info
  * [2811] improve "auto" audio selection picks the "best" audio given the input codec and output formats
  * [2812] show the correct audio codec in the audio list when it has been changed because of incompatibility with source codec or output format
  * [2813] fix initialization of chapter list when editing queued job Chapter titles the user entered were lost when editing a queued job
  * [2814] fix a Gtk-CRITICAL error when editing chapter names
  * [2815] dvdnav: read error recovery - patch libdvdnav seek to guarantee the position will move forward when making a seek request to a position that is after the current position - when a read error is detected, seek forward and retry
* Sat Sep  5 2009 pascal.bleser@opensuse.org
- new package
